<?php

namespace App\Http\Controllers;

use App\Models\Psicologos;
use Illuminate\Http\Request;

class PsicologosController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $psicologos = Psicologos::paginate(5);
        return view('psicologos.index', compact('psicologos'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('psicologos.crear');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // Validar los datos
        $request->validate([
            'nombre' => 'required|string|max:255',
            'apellido' => 'required|string|max:255',
            'email' => 'required|email|unique:psicologos,email',
            'telefono' => 'nullable|string|max:20',
            'especialidad' => 'required|string|max:255',
            'biografia' => 'nullable|string',
        ]);

        // Crear el nuevo psicólogo con estado "activo"
        $psicologoData = $request->all();
        $psicologoData['estado'] = 'activo'; // Establecer estado a "activo"

        Psicologos::create($psicologoData);

        // Redireccionar o mostrar mensaje de éxito
        return redirect()->route('psicologos.index')->with('success', 'Psicólogo agregado con éxito.');
    }



    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Psigologos  $psigologos
     * @return \Illuminate\Http\Response
     */
    public function show(Psicologos $psigologos)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Psigologos  $psigologos
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $psicologo = Psicologos::findOrFail($id);
        return view('psicologos.editar', compact('psicologo'));
    }


    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Psigologos  $psigologos
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        // Validar los datos
        $request->validate([
            'nombre' => 'required|string|max:255',
            'apellido' => 'required|string|max:255',
            'email' => 'required|email|unique:psicologos,email,' . $id,
            'telefono' => 'nullable|string|max:20',
            'especialidad' => 'required|string|max:255',
            'biografia' => 'nullable|string',
        ]);

        // Encontrar el psicólogo por ID
        $psicologo = Psicologos::findOrFail($id);

        // Actualizar los datos
        $psicologo->update($request->all());

        // Redirigir o mostrar mensaje de éxito
        return redirect()->route('psicologos.index')->with('success', 'Psicólogo actualizado con éxito.');
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Psigologos  $psigologos
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        // Buscar el psicólogo por su ID
        $psicologo = Psicologos::findOrFail($id);

        // Verificar el estado actual y actuar en consecuencia
        if ($psicologo->estado === 'activo') {
            // Cambiar el estado a "desactivado"
            $psicologo->estado = 'desactivado';
            $mensaje = 'Psicólogo desactivado con éxito.';
        } else {
            // Cambiar el estado a "activo"
            $psicologo->estado = 'activo';
            $mensaje = 'Psicólogo reactivado con éxito.';
        }

        $psicologo->save();

        // Redireccionar o mostrar mensaje de éxito
        return redirect()->route('psicologos.index')->with('success', $mensaje);
    }
}
