<?php

namespace App\Http\Controllers;

use App\Models\Psiquiatria;
use App\Models\Pacientes;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;

class PsiquiatriaController extends Controller
{
    public function index(Request $request)
    {
        $query = $request->get('query');

        $psiquiatria = Psiquiatria::with('paciente', 'user') // Asegúrate de que las relaciones existan
            ->when($query, function ($queryBuilder) use ($query) {
                $queryBuilder->whereHas('paciente', function ($q) use ($query) {
                    $q->where('nombre', 'LIKE', "%{$query}%")
                        ->orWhere('apellido', 'LIKE', "%{$query}%");
                })->orWhereHas('user', function ($q) use ($query) {
                    $q->where('name', 'LIKE', "%{$query}%");
                });
            })
            ->paginate(10); // Asegúrate de usar paginate()

        return view('psiquiatria.index', compact('psiquiatria'));
    }

    public function create()
    {
        // URL de Firestore para obtener los documentos de la colección 'pacientes'
        $firestoreUrl = 'https://firestore.googleapis.com/v1/projects/pixie-b4bc3/databases/(default)/documents/pacientes';

        // Realiza la solicitud HTTP a Firestore para obtener los pacientes
        $response = Http::get($firestoreUrl);

        // Comprueba si la solicitud falló
        if ($response->failed()) {
            return back()->withErrors(['error' => 'Error al obtener los pacientes desde Firestore']);
        }

        // Obtiene los documentos desde la respuesta
        $documents = $response->json()['documents'] ?? [];

        // Procesa los documentos para extraer los datos de cada paciente
        $pacientes = [];
        foreach ($documents as $document) {
            $fields = $document['fields'] ?? []; // Verifica si el campo 'fields' existe

            // Añade comprobaciones para cada campo
            $pacientes[] = [
                'id' => isset($document['name']) ? basename($document['name']) : 'N/A', // Validar si 'name' existe
                'nombre' => $fields['name']['stringValue'] ?? 'N/A',
                'apellido' => $fields['lastName']['stringValue'] ?? 'N/A',
                'email' => $fields['email']['stringValue'] ?? 'N/A',
                'telefono' => $fields['phone']['stringValue'] ?? 'N/A',
                'ansiedad' => $fields['resultados']['mapValue']['fields']['ansiedad']['integerValue'] ?? 'N/A',
                'depresion' => $fields['resultados']['mapValue']['fields']['depresion']['integerValue'] ?? 'N/A',
                'estres' => $fields['resultados']['mapValue']['fields']['estres']['integerValue'] ?? 'N/A',
            ];
        }

        // Obtiene todos los usuarios de la base de datos local
        $usuarios = User::all();

        // Retorna la vista con los pacientes y los usuarios
        return view('psiquiatria.create', compact('pacientes', 'usuarios'));
    }


    public function store(Request $request)
    {
        $request->validate([
            'paciente_id' => 'required|exists:pacientes,id',
            'user_id' => 'nullable|exists:users,id', // Cambiado a nullable
            'observaciones' => 'required|string|max:255',
        ]);

        Psiquiatria::create($request->all());
        return redirect()->route('psiquiatria.index')->with('success', 'Psiquiatría creada con éxito.');
    }

    public function edit($id)
    {
        $psiquiatria = Psiquiatria::findOrFail($id);
        $pacientes = Pacientes::all();
        $usuarios = User::all();
        return view('psiquiatria.edit', compact('psiquiatria', 'pacientes', 'usuarios'));
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'paciente_id' => 'required|exists:pacientes,id',
            'user_id' => 'nullable|exists:users,id', // Cambiado a nullable
            'observaciones' => 'required|string|max:255',
        ]);

        $psiquiatria = Psiquiatria::findOrFail($id);
        $psiquiatria->update($request->all());
        return redirect()->route('psiquiatria.index')->with('success', 'Psiquiatría actualizada con éxito.');
    }
}
